@@ -36,8 +36,8 @@ def gen_kdata_schemas():
 
 if __name__ == '__main__':
     # zip_dir(ZVT_TEST_DATA_PATH, zip_file_name=DATA_SAMPLE_ZIP_PATH)
-    # gen_exports('api')
-    gen_exports('recorders')
+    gen_exports('contract',export_from_package=False)
+    # gen_exports('recorders')
     # gen_exports('domain')
     # gen_exports('informer')
     # gen_exports('utils')
