@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
 
-from zvt.contract import Exchange
 from zvt.contract.api import df_to_db
 from zvt.contract.recorder import Recorder
 from zvt.domain.meta.stockhk_meta import Stockhk
@@ -12,7 +11,7 @@ class EMStockhkRecorder(Recorder):
     data_schema = Stockhk
 
     def run(self):
-        df = em_api.get_tradable_list(entity_type='stock', exchange=Exchange.hk)
+        df = em_api.get_tradable_list(entity_type='stockhk')
         self.logger.info(df)
         df_to_db(df=df, data_schema=self.data_schema, provider=self.provider, force_update=True)
 
