@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
 
-from zvt.contract import Exchange
 from zvt.contract.api import df_to_db
 from zvt.contract.recorder import Recorder
 from zvt.domain.meta.stockus_meta import Stockus
@@ -12,10 +11,9 @@ class EMStockusRecorder(Recorder):
     data_schema = Stockus
 
     def run(self):
-        for exchange in [Exchange.nasdaq, Exchange.nyse]:
-            df = em_api.get_tradable_list(entity_type='stock', exchange=exchange)
-            self.logger.info(df)
-            df_to_db(df=df, data_schema=self.data_schema, provider=self.provider, force_update=True)
+        df = em_api.get_tradable_list(entity_type='stockus')
+        self.logger.info(df)
+        df_to_db(df=df, data_schema=self.data_schema, provider=self.provider, force_update=True)
 
 
 if __name__ == '__main__':
