@@ -24,7 +24,8 @@ class JqChinaStockKdataRecorder(FixedCycleDataRecorder):
     # 只是为了把recorder注册到data_schema
     data_schema = StockKdataCommon
 
-    def __init__(self, force_update=True, sleeping_time=10, exchanges=None, entity_ids=None, codes=None, day_data=False,
+    def __init__(self, force_update=True, sleeping_time=10, exchanges=None, entity_ids=None,
+                 code=None, codes=None, day_data=False,
                  entity_filters=None, ignore_failed=True, real_time=False, fix_duplicate_way='ignore',
                  start_timestamp=None, end_timestamp=None, level=IntervalLevel.LEVEL_1DAY, kdata_use_begin_time=False,
                  one_day_trading_minutes=24 * 60, adjust_type=AdjustType.qfq) -> None:
@@ -33,7 +34,7 @@ class JqChinaStockKdataRecorder(FixedCycleDataRecorder):
         self.data_schema = get_kdata_schema(entity_type='stock', level=level, adjust_type=adjust_type)
         self.jq_trading_level = to_jq_trading_level(level)
 
-        super().__init__(force_update, sleeping_time, exchanges, entity_ids, codes, day_data, entity_filters,
+        super().__init__(force_update, sleeping_time, exchanges, entity_ids, code, codes, day_data, entity_filters,
                          ignore_failed, real_time, fix_duplicate_way, start_timestamp, end_timestamp, level,
                          kdata_use_begin_time, one_day_trading_minutes)
 
@@ -133,4 +134,4 @@ if __name__ == '__main__':
     Stock1wkHfqKdata.record_data(codes=['300999'])
 
 # the __all__ is generated
-__all__ = ['JqChinaStockKdataRecorder']
\ No newline at end of file
+__all__ = ['JqChinaStockKdataRecorder']
